package app

import (
	"context"
	"errors"

	"coopcloud.tech/abra/cli/internal"
	"coopcloud.tech/abra/pkg/client"
	stack "coopcloud.tech/abra/pkg/client/stack"
	"coopcloud.tech/abra/pkg/config"
	"github.com/sirupsen/logrus"
	"github.com/urfave/cli/v2"
)

var appUndeployCommand = &cli.Command{
	Name:    "undeploy",
	Aliases: []string{"u"},
	Usage:   "Undeploy an app",
	Description: `
This does not destroy any of the application data. However, you should remain
vigilant, as your swarm installation will consider any previously attached
volumes as eligiblef or pruning once undeployed.
`,
	Action: func(c *cli.Context) error {
		appName := c.Args().First()
		if appName == "" {
			internal.ShowSubcommandHelpAndError(c, errors.New("no app name provided"))
		}

		appFiles, err := config.LoadAppFiles("")
		if err != nil {
			logrus.Fatal(err)
		}

		appEnv, err := config.GetApp(appFiles, appName)
		if err != nil {
			logrus.Fatal(err)
		}

		ctx := context.Background()
		host := appFiles[appName].Server
		cl, err := client.New(host)
		if err != nil {
			logrus.Fatal(err)
		}

		rmOpts := stack.Remove{Namespaces: []string{appEnv.StackName()}}
		if err := stack.RunRemove(ctx, cl, rmOpts); err != nil {
			logrus.Fatal(err)
		}

		return nil
	},
}
